.. include:: ../links.rst

Introduction
============

Many of the very good IDE's out there are "closed" in the sense
that they are limited in terms of extensibility and communication with other tools.
Further, many writers and programmers want to change their editor to something else
while retaining the features of an IDE.

PIDA was designed with these problems in mind.
PIDA's motto is to reuse the tools that proved to be useful and solid;
thus, PIDA provides the glue for them.
PIDA is written in Python_ and uses PyGTK_.
It is easily extensible through plugins
and can embed any editor provided someone writes an adapter for it.

PIDA has a number of unique features, such as

- The ability to set your preferred text editor
- Integration with most of the popular version control systems
- Multiple useful plugins
- An easy to use console interface
- Hotkey support
- Project Management
